@@ -20,7 +20,9 @@
 # 15. aux.traceratio.max   : compute trace ratio problem for maximal basis
 # 16. aux.pinv             : use SVD and NumPy scheme
 # 17. aux.bicgstab         : due to my stupidity, now Rlinsolve can't be used.
-# 18. aux_oosprocess       : data processign for oos prediction
+# 18. aux.oosprocess       : data processign for oos prediction
+# 19. aux.findmaxidx       : find the row and column index of maximal elements
+# 20. aux.randpartition    : given 1:n, divide it into K random partitions without replacement
 
 #  ------------------------------------------------------------------------
 # 0. AUX.TYPECHECK
@@ -236,6 +238,7 @@ aux.preprocess.hidden <- function(data,type=c("null","center","scale","cscale","
 #'
 #' @param n the number of points to be generated.
 #' @param noise level of additive white noise.
+#'
 #' @param dname name of a predefined shape. Should be one of \describe{
 #' \item{\code{"swiss"}}{swiss roll}
 #' \item{\code{"crown"}}{crown}
@@ -245,34 +248,43 @@ aux.preprocess.hidden <- function(data,type=c("null","center","scale","cscale","
 #' \item{\code{"bswiss"}}{broken swiss}
 #' \item{\code{"cswiss"}}{cut swiss}
 #' \item{\code{"twinpeaks"}}{two peaks}
+#' \item{\code{"sinusoid"}}{sinusoid on the circle}
+#' \item{\code{"mobius"}}{mobius strip embedded in \eqn{\mathbf{R}^3}}
+#' \item{\code{"R12in72"}}{12-dimensional manifold in \eqn{\mathbf{R}^{12}}}
 #' }
+#' @param ... extra parameters for the followings #' \tabular{lll}{
+#' parameter \tab dname \tab description \cr
+#' \code{ntwist} \tab \code{"mobius"} \tab number of twists
+#' }
+#'
 #' @return an \eqn{(n\times 3)} matrix of generated data by row.
-#' @examples
-#' ## Generate samples for three different shapes
-#' d1 = aux.gensamples(dname="twinpeaks",noise=0.01)
-#' d2 = aux.gensamples(dname="ribbon",noise=0.01)
-#' d3 = aux.gensamples(dname="crown", noise=0.01)
 #'
-#' \dontrun{
-#' casenames = c("swiss","crown","helix","saddle","ribbon","bswiss","cswiss","twinpeaks")
-#' for (i in 1:length(casenames)){
-#'   data = aux.gensamples(n=sample(1000:2000,1),noise=runif(1)[1],dname=casenames[i])
-#' }
-#' }
 #' @references
-#' \insertRef{van_der_maaten_dimensionality_2009}{Rdimtools}
+#' \insertRef{hein_intrinsic_2005}{Rdimtools}
 #'
+#' \insertRef{van_der_maaten_dimensionality_2009}{Rdimtools}
 #'
 #' @author Kisung You
 #' @rdname aux_gensamples
 #' @export
-aux.gensamples <- function(n=496,noise=0.1,dname="swiss"){
-  params = as.list(environment())
-  dtype = params$dname
-  casenames = c("swiss","crown","helix","saddle","ribbon","bswiss","cswiss","twinpeaks")
-  if (!is.element(dtype,casenames)){
-    message("function gensamples:: use one of specificed types")
-    stop()
+aux.gensamples <- function(n=496,noise=0.01,
+                           dname=c("swiss","crown","helix","saddle","ribbon","bswiss","cswiss","twinpeaks","sinusoid",
+                                   "mobius","R12in72"), ...){
+  #params = as.list(environment())
+  n     = as.integer(n)
+  noise = as.double(noise)
+  dtype = (match.arg(dname))
+
+  ## extra parameters
+  extrapar = list(...)
+  #   1. ntwist
+  if ("ntwist" %in% names(extrapar)){
+    ntwist = as.integer(extrapar$ntwist)
+  } else {
+    ntwist= as.integer(10)
+  }
+  if ((ntwist<1)||(is.na(ntwist))||(length(ntwist)>1)||(is.infinite(ntwist))){
+    stop("* aux.gensamples : 'ntwist' should be a positive integer.")
   }
 
   # 2. type branching
@@ -359,6 +371,37 @@ aux.gensamples <- function(n=496,noise=0.1,dname="swiss"){
     hz = tanh(3-6*yi)
 
     highD = cbind(hx,hy,hz)+matrix(rnorm(n*3,sd=noise),c(n,3))
+  } else if (dtype=="sinusoid"){
+    # hein audibert
+    tt = runif(n, min=0, max=(2*3.141592))
+
+    hx = sin(tt)
+    hy = cos(tt)
+    hz = sin(150*tt)/10
+
+    highD = cbind(hx,hy,hz)+matrix(rnorm(n*3,sd=noise),nrow=n)
+  } else if (dtype=="mobius"){
+    u = runif(n,-1,1)
+    v = runif(n,0,2*3.141592)
+
+    hx = (1+(u/2)*cos(ntwist*v/2))*(cos(v))
+    hy = (1+(u/2)*cos(ntwist*v/2))*(sin(v))
+    hz = (u/2)*sin(ntwist*v/2)
+
+    highD = cbind(hx,hy,hz)+matrix(rnorm(n*3,sd=noise),nrow=n)
+  } else if (dtype=="R12in72"){
+    xi = array(0,c(n,24)) # without noise
+    for (it in 1:n){
+      alpha = runif(12)
+      for (i in 1:11){
+        xi[it,(2*i-1)] = alpha[i+1]*cos(2*pi*alpha[i])
+        xi[it,2*i]     = alpha[i+1]*sin(2*pi*alpha[i])
+      }
+      xi[it,23] = alpha[1]*cos(2*pi*alpha[12])
+      xi[it,24] = alpha[1]*sin(2*pi*alpha[12])
+    }
+
+    highD = cbind(xi,xi,xi) + matrix(rnorm(n*72,sd=noise),nrow=n)
   }
   return(highD)
 }
@@ -1493,3 +1536,38 @@ aux.oospreprocess <- function(data, trfinfo){
   }
   return(output)
 }
+
+# 19. aux_findmaxidx       : find the row and column index of maxi --------
+#' @keywords internal
+#' @noRd
+aux.findmaxidx <- function(A){
+  # 19. aux_findmaxidx       : find the row and column index of maximal elements
+  output = which(A==max(A), arr.ind=TRUE)
+  if (nrow(output)>1){
+    return(output[1,])
+  } else {
+    return(output)
+  }
+}
+
+
+# 20. aux.randpartition ---------------------------------------------------
+#     given 1:n, divide it into K random partitions without replacement
+#' @keywords internal
+#' @noRd
+aux.randpartition <- function(n, K){
+  output = list()
+  if (K==1){
+    output = list()
+    output[[1]] = 1:n
+  } else {
+    listall = 1:n
+    singleK = round(n/K)
+    for (i in 1:(K-1)){
+      output[[i]] = sample(listall, singleK, replace = FALSE)
+      listall = setdiff(listall, output[[i]])
+    }
+    output[[K]] = listall
+  }
+  return(output)
+}
