@@ -96,10 +96,6 @@ do.sne <- function(X,ndim=2,perplexity=30,eta=0.05,maxiter=2000,
   if ((!is.numeric(momentum))||(is.na(momentum))||(is.infinite(momentum))||(momentum<=0)){
     stop("* do.sne : 'momentum' should be a positive real number.")
   }
-  #   2-6. (char) preprocess = 'center'
-  if (!is.element(preprocess,c("null","center","decorrelate","whiten"))){
-    stop("* do.sne : 'preprocess' should have one of 4 options.")
-  }
 
   algpreprocess = match.arg(preprocess)
   tmplist = aux.preprocess.hidden(X,type=algpreprocess,algtype="nonlinear")
